<!--
 * @Author: zouyaoji@https://github.com/zouyaoji
 * @Date: 2021-10-27 15:54:11
 * @LastEditTime: 2021-11-07 15:38:40
 * @LastEditors: zouyaoji
 * @Description:
 * @FilePath: \vue-cesium@next\website\docs\en-US\i18n.md
-->

## Internationalization

VueCesium components are using Chinese **by default**, if you wish you use other languages, you can get you answer by keep reading.

### Global configuration

VueCesium provides global configurations

```typescript
import { createApp } from 'vue'
import VueCesium from 'vue-cesium'
import enUS from 'vue-cesium/es/locale/lang/en-us'

const app = createApp(App)
app.use(VueCesium, {
  locale: enUS
})
app.mount('#app')
```

### VcConfigProvider

VueCesium also provides a Vue component [VcConfigProvider](/#/en-US/component/vc-config-provider)
for globally configuring locale and other settings.

```html
<template>
  <vc-config-provider :locale="locale">
    <vc-viewer>
      <vc-navigation></vc-navigation>
    </vc-viewer>
  </vc-config-provider>
</template>

<script>
  import { defineComponent } from 'vue'
  import { VcConfigProvider, VcViewer, VcNavigation } from 'vue-cesium'

  import enUS from 'vue-cesium/es/locale/lang/en-us'

  export default defineComponent({
    components: {
      VcConfigProvider,
      VcViewer,
      VcNavigation
    },
    setup() {
      return {
        locale: enUS
      }
    }
  })
</script>
```

<!-- ### CDN Usage

If you are using VueCesium via CDN, then you need to do this, let's again take
unpkg as an example

```html
<script src="//unpkg.com/vue-cesium@next/dist/locale/zh-cn">
  app.use(VueCesium, {
    locale: VueCesium.lang.zh
  })
</script>
``` -->

[Supported Language List](https://github.com/zouyaoji/vue-cesium/tree/dev/packages/locale/lang)

<ul class="language-list">
  <li>Simplified Chinese (zh-hans)</li>
  <li>English (en-us)</li>
</ul>

If you need any other languages, [PR](https://github.com/zouyaoji/vue-cesium/pulls)
is always welcomed, you only need to add a language file at
[here](https://github.com/zouyaoji/vue-cesium/tree/dev/packages/locale/lang).

### FAQs

#### If I want to replace the default language pack to reduce the size, how do I do?

When the default language of your app is not **Chinese**, you will be going to need
to import another language file, which will increase the bundle size since you have
both **English** and **Your desired language** bundled,
you can use the plugin [NormalModuleReplacementPlugin](https://webpack.js.org/plugins/normal-module-replacement-plugin/#root)
provided by [webpack](https://webpack.js.org) to replace the default language file,
so that you will only get **1** language file bundled.
Add the code below into your `webpack.config.js` to get it work.

> webpack.config.js

```typescript
{
  plugins: [new webpack.NormalModuleReplacementPlugin(/vue-cesium[\/\\]lib[\/\\]locale[\/\\]lang[\/\\]zh-hans/, 'vue-cesium/lib/locale/lang/en-us')]
}
```
