<!--
 * @Author: zouyaoji@https://github.com/zouyaoji
 * @Date: 2021-10-27 15:54:11
 * @LastEditTime: 2021-11-07 15:38:25
 * @LastEditors: zouyaoji
 * @Description:
 * @FilePath: \vue-cesium@next\website\docs\zh-CN\i18n.md
-->

## 国际化

VueCesium 组件内部**默认**使用英语，若希望使用其他语言，可以参考下面的方案。

### 全局配置

VueCesium 提供了全局配置国际化的设置。

```typescript
import { createApp } from 'vue'
import VueCesium from 'vue-cesium'
import enUS from 'vue-cesium/es/locale/lang/en-us'

const app = createApp(App)
app.use(VueCesium, {
  locale: enUS
})
app.mount('#app')
```

### VcConfigProvider

VueCesium 还提供了一个 Vue 组件 [VcConfigProvider](/#/zh-CN/component/vc-config-provider) 用于全局配置国际化的设置。

```html
<template>
  <vc-config-provider :locale="locale">
    <vc-viewer>
      <vc-navigation></vc-navigation>
    </vc-viewer>
  </vc-config-provider>
</template>

<script>
  import { defineComponent } from 'vue'
  import { VcConfigProvider, VcViewer, VcNavigation } from 'vue-cesium'

  import enUS from 'vue-cesium/es/locale/lang/en-us'

  export default defineComponent({
    components: {
      VcConfigProvider,
      VcViewer,
      VcNavigation
    },
    setup() {
      return {
        locale: enUS
      }
    }
  })
</script>
```

<!-- ### CDN 用法

如果你是使用 CDN 引入的 VueCesium，那你将需要这样做，以 unpkg 举例

```html
<script src="//unpkg.com/vue-cesium@next">
  app.use(VueCesium, {
    locale: VueCesium.lang.zh
  })
</script>
``` -->

[支持的语言列表](https://github.com/zouyaoji/vue-cesium/tree/dev/packages/locale/lang)

<ul class="language-list">
  <li>简体中文（zh-hans）</li>
  <li>英文（en-us）</li>
</ul>

如果你需要使用其他的语言，欢迎贡献 [PR](https://github.com/zouyaoji/vue-cesium/pulls) 只需在[这里](https://github.com/zouyaoji/vue-cesium/tree/dev/packages/locale/lang) 添加一个语言配置文件即可。

### 常见问题

#### 如果我想要替换默认语言包来减小打包体积，应该怎么做？

当你的应用默认不是使用**中文**的时候，你需要额外引入一个新的语言，这样会使得没有用到的语言文件被打包，会增加最终产物的文件大小，如果你非常在意最终产物文件的大小，你可以使用 [webpack](https://webpack.js.org) 提供的 [NormalModuleReplacementPlugin](https://webpack.js.org/plugins/normal-module-replacement-plugin/#root) 插件替换默认语言包。你可以把以下代码添加进 `webpack.config.js` 文件中来应用这个插件。

> webpack.config.js

```typescript
{
  plugins: [new webpack.NormalModuleReplacementPlugin(/vue-cesium[\/\\]lib[\/\\]locale[\/\\]lang[\/\\]zh-hans/, 'vue-cesium/lib/locale/lang/en-us')]
}
```
